
***************************
* File: Info_generale.do 
* Questionnaire type: Health Facility
* Country: Madagascar
*****************************

version 10.1
cd "Source\Madagascar 2006 P H\"
capture clear
capture log close
clear
set mem 700m
set more off


use  "Source\4- Data\4.1 Raw Data\First Round\phagedis\Info_generale.dta"


**************************************************
***   Ensure all variables are present and labeled.
**************************************************
cd "Source\Madagascar 2006 P H\Extra\First Round\phagedis"
log using "Info_generale", replace
codebook, compact
log close

label var delai_csbm_n "delai normal entre envoi BC et livraison medicaments pour CS"

**************************************************
***  Ensure response value labels are correct.
**************************************************
label save using "Info_generale label values", replace

**************************************************
***    Unique identifiers: ID
**************************************************
egen fivondronana_code=group(fivondronana)
label var fivondronana_code "fivondronana code"
order  fivondronana fivondronana_code

**************************************************
***    Identify skip patterns
**************************************************
* Recode missing values to Stata missing values, for tests and data inspection.
quietly mvdecode _all,mv (-666 = .d \ -777 = .n \ -888 = .l \ -999 = .r) 

**************************************************
***    Identify illegal responses
**************************************************

log using "Info_generale label inspect", replace
inspect
log close

**************************************************
***   Identify outliers
**************************************************
mvdecode _all, mv(0 = .z)
grubbs   tps_drspf tps_salama tps_admin tps_cirfin tps_tresor delai_norm1 delai_long1 delai_norm2 delai_long2 delai_norm3 delai_long3 delai_norm4 delai_long4 delai_norm5 delai_long5 nb_com_sal delai_csbm_n delai_csbm_l delai_csbe_n delai_csbe_l delai_csbp_n delai_csbp_l delai_bc_n delai_bc_l nb_com_phaco marg_phadis marg_phacom, level(99.99)
sum grubbs*
drop grubbs* 
mvencode _all, mv(.z = 0)

**************************************************
*** FINAL   : Delivrables
**************************************************

*Codebook
cd "Source\4- Data\4.3. Clean Data\4.3.3. Data Code Book\First Round\phagedis"
log using "Info_generale codebook", replace
codebook, compact
log close

*Save cleaned data
cd "Source\4- Data\4.3. Clean Data\4.3.1. Final Data\First Round\phagedis"
save Info_generale_cleaned_data.dta, replace
