
***************************
* File: commune_rupture_stock.do 
* Questionnaire type: Health Facility
* Country: Madagascar
*****************************

version 10.1
cd "Source\Madagascar 2006 P H\"
capture clear
capture log close
clear
set mem 700m
set more off


use "Source\4- Data\4.1 Raw Data\First Round\phagedis\commune_rupture_stock.dta"


**************************************************
***    Ensure all variables are present and labeled.
**************************************************
cd "Source\First Round\phagedis"
log using "commune_rupture_stock", replace
codebook, compact
log close

**************************************************
***    Ensure response value labels are correct.
**************************************************
label save using "commune_rupture_stock label values", replace

**************************************************
***    Unique identifiers: ID
**************************************************
egen fivondronana_code=group(fivondronana)
label var fivondronana_code "fivondronana code"
order  fivondronana fivondronana_code

local mylist "  nom_com1 csb1_com1 csb2_com1 nom_com2 csb1_com2 csb2_com2 nom_com3 csb1_com3 csb2_com3"
levelsof  typ_med, local( typ_med_levels)
foreach v of varlist   nom_com1 csb1_com1 csb2_com1 nom_com2 csb1_com2 csb2_com2 nom_com3 csb1_com3 csb2_com3{
local l`v' : variable label `v'
}
reshape wide  nom_com1 csb1_com1 csb2_com1 nom_com2 csb1_com2 csb2_com2 nom_com3 csb1_com3 csb2_com3, i( fivondronana_code) j( typ_med)
foreach x of local mylist{
foreach y of local  typ_med_levels{
label var `x'`y' "`l`x''"
}
}


**************************************************
***    Recode missing values
***************************************************

*    DECODE MISSING VALUES
# d ;
qui mvdecode  csb*, mv(
3=.d);
# d cr;

**************************************************
***    Identify skip patterns
**************************************************
* Recode missing values to Stata missing values, for tests and data inspection.
quietly mvdecode _all,mv (-666 = .d \ -777 = .n \ -888 = .l \ -999 = .r) 


**************************************************
***    Identify illegal responses
**************************************************

log using "commune_rupture_stock label inspect", replace
inspect
log close

**************************************************
*** FINAL   : Delivrables
**************************************************

*Codebook
cd "Source\4- Data\4.3. Clean Data\4.3.3. Data Code Book\First Round\phagedis"
log using "commune_rupture_stock codebook", replace
codebook, compact
log close

*Save cleaned data
cd "Source\4- Data\4.3. Clean Data\4.3.1. Final Data\First Round\phagedis"
save commune_rupture_stock_cleaned_data.dta, replace
