
***************************
* File: rupture_stock.do 
* Questionnaire type: Health Facility
* Country: Madagascar
*****************************

version 10.1
cd "Source\Madagascar 2006 P H\"
capture clear
capture log close
clear
set mem 700m
set more off


use  "Source\4- Data\4.1 Raw Data\First Round\phagedis\rupture_stock.dta"


**************************************************
***    Ensure all variables are present and labeled.
**************************************************
cd "Source\First Round\phagedis"
log using "rupture_stock", replace
codebook, compact
log close


**************************************************
***    Ensure response value labels are correct.
**************************************************
label save using "rupture_stock label values", replace

**************************************************
***    Unique identifiers: ID
**************************************************
egen fivondronana_code=group(fivondronana)
label var fivondronana_code "fivondronana code"
order  fivondronana fivondronana_code

local mylist "  dispon jour_nodisp rsn_rupt disp_avant nb_jour_rupt"
levelsof  typ_med, local( typ_med_levels)
foreach v of varlist   dispon jour_nodisp rsn_rupt disp_avant nb_jour_rupt{
local l`v' : variable label `v'
}
reshape wide   dispon jour_nodisp rsn_rupt disp_avant nb_jour_rupt, i( fivondronana_code) j( typ_med)
foreach x of local mylist{
foreach y of local  typ_med_levels{
label var `x'`y' "`l`x''"
}
}

**************************************************
***   Identify skip patterns
**************************************************
* Recode missing values to Stata missing values, for tests and data inspection.
quietly mvdecode _all,mv (-666 = .d \ -777 = .n \ -888 = .l \ -999 = .r) 

**************************************************
***   Identify illegal responses
**************************************************

log using "rupture_stock label inspect", replace
inspect
log close

**************************************************
***   Identify outliers
**************************************************
log using "rupture_stock grubbs", replace
preserve
global discrete (rsn_rupt* disp_avant* dispon* )
global name ( fivondronana)
drop $discrete $name 
mvdecode _all, mv(0 = .z)
grubbs _all, level(99.99)
sum grubbs*
drop grubbs* 
mvencode _all, mv(.z = 0)
log close
restore

**************************************************
*** FINAL   : Delivrables
**************************************************

*Codebook
cd "Source\4- Data\4.3. Clean Data\4.3.3. Data Code Book\First Round\phagedis"
log using "rupture_stock codebook", replace
codebook, compact
log close

*Save cleaned data
cd "Source\4- Data\4.3. Clean Data\4.3.1. Final Data\First Round\phagedis"
save rupture_stock_cleaned_data.dta, replace
