
***************************
* File: situation_livraison.do 
* Questionnaire type: Health Facility
* Country: Madagascar
*****************************

version 10.1
cd "Source\Madagascar 2006 P H\"
capture clear
capture log close
clear
set mem 700m
set more off


use "Source\4- Data\4.1 Raw Data\First Round\phagedis\situation_livraison.dta"


**************************************************
***    Ensure all variables are present and labeled.
**************************************************
cd "Source\First Round\phagedis"
log using "situation_livraison", replace
codebook, compact
log close

label var condition "conditionnement du medicament"
**************************************************
***    Ensure response value labels are correct.
**************************************************
label save using "situation_livraison label values", replace

**************************************************
***    Unique identifiers: ID
**************************************************
egen  csb_code=group( csb)
label var  csb_code " csb code"
order  csb  csb_code
replace csb_code=106 if fivondronana=="TSARATANANA" & csb=="CSB II SAROBARATRA"

local mylist "  condition qte_com1 prix1 qte_liv1 valeur1 qte_com2 prix2 qte_liv2 valeur2"
levelsof  typ_med, local( typ_med_levels)
foreach v of varlist  condition qte_com1 prix1 qte_liv1 valeur1 qte_com2 prix2 qte_liv2 valeur2{
local l`v' : variable label `v'
}
reshape wide condition qte_com1 prix1 qte_liv1 valeur1 qte_com2 prix2 qte_liv2 valeur2, i( csb_code) j( typ_med)
foreach x of local mylist{
foreach y of local  typ_med_levels{
label var `x'`y' "`l`x''"
}
}

**************************************************
***    Identify skip patterns
**************************************************
* Recode missing values to Stata missing values, for tests and data inspection.
quietly mvdecode _all,mv (-666 = .d \ -777 = .n \ -888 = .l \ -999 = .r) 

**************************************************
***    Identify illegal responses
**************************************************

log using "situation_livraison label inspect", replace
inspect
log close

**************************************************
***   Identify outliers
**************************************************

mvdecode _all, mv(0 = .z)
grubbs  condition* qte_com1* prix1* qte_liv1* valeur1* qte_com2* prix2* qte_liv2* valeur2*, level(99.99)
sum grubbs*
drop grubbs* 
mvencode _all, mv(.z = 0)

**************************************************
*** FINAL   : Delivrables
**************************************************

*Codebook
cd "Source\4- Data\4.3. Clean Data\4.3.3. Data Code Book\First Round\phagedis"
log using "situation_livraison codebook", replace
codebook, compact
log close

*Save cleaned data
cd "Source\4- Data\4.3. Clean Data\4.3.1. Final Data\First Round\phagedis"
save situation_livraison_cleaned_data.dta, replace
